@@ -6,7 +6,6 @@
 #
 #---------------------------------------------#
 import datetime
-from django.utils.timezone import utc
 
 from django.db import models
 from django.core.mail import EmailMultiAlternatives
@@ -16,6 +15,7 @@ from django.conf import settings
 
 from mailqueue import defaults
 
+
 class MailerMessageManager(models.Manager):
     def send_queued(self, limit=None):
         if limit is None:
@@ -24,6 +24,7 @@ class MailerMessageManager(models.Manager):
         for email in self.filter(sent=False)[:limit]:
             email.send()
 
+
 class MailerMessage(models.Model):
     subject = models.CharField(max_length=250, blank=True, null=True)
     to_address = models.EmailField(max_length=250)
@@ -42,8 +43,9 @@ class MailerMessage(models.Model):
 
     def send(self):
         if not self.sent:
-            if settings.USE_TZ:
+            if getattr(settings, 'USE_TZ', False):
                 # This change breaks SQLite usage.
+                from django.utils.timezone import utc
                 self.last_attempt = datetime.datetime.utcnow().replace(tzinfo=utc)
             else:
                 self.last_attempt = datetime.datetime.now()
